# Copyright 2020-2024 Flavio Garcia
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from peasant.security import keyring
from peasant.security.jwk import to_jwk
from cryptography.hazmat.bindings._rust import openssl
from unittest import TestCase
from jose import jwk


class KeyringTestCase(TestCase):

    def test_ec(self):
        from pprint import pprint
        ec_key: openssl.ec.ECPrivateKey = keyring.generate_key("ec")
        self.assertIsInstance(ec_key, openssl.ec.ECPrivateKey)
        pem = keyring.key_to_pem(ec_key)
        ec_key_from_pem = keyring.pem_to_private_key(pem)
        self.assertIsInstance(ec_key_from_pem, openssl.ec.ECPrivateKey)
        ec_key_from_pem_pem = keyring.key_to_pem(ec_key_from_pem)
        self.assertEqual(pem, ec_key_from_pem_pem)
        pprint(to_jwk(ec_key))
        jwk_key = jwk.construct(to_jwk(ec_key))
        jwk_pem = keyring.key_to_pem(jwk_key)
        print(jwk_pem)

    def test_rsa(self):
        from pprint import pprint
        rsa_key: openssl.ec.ECPrivateKey = keyring.generate_key(size=2048)
        self.assertIsInstance(rsa_key, openssl.rsa.RSAPrivateKey)
        pem = keyring.key_to_pem(rsa_key)
        ec_rsa_from_pem = keyring.pem_to_private_key(pem)
        self.assertIsInstance(ec_rsa_from_pem, openssl.rsa.RSAPrivateKey)
        rsa_key_from_pem_pem = keyring.key_to_pem(ec_rsa_from_pem)
        self.assertEqual(pem, rsa_key_from_pem_pem)
        pprint(to_jwk(rsa_key))
        jwk_key = jwk.construct(to_jwk(rsa_key))
        jwk_pem = keyring.key_to_pem(jwk_key)
        print(jwk_pem)
